@@ -18,9 +18,10 @@ pub fn drop(cap: Capability) -> Result<()> {
     let ret = unsafe { libc::prctl(nr::PR_CAPBSET_DROP, libc::c_uint::from(cap.index()), 0, 0) };
     match ret {
         0 => Ok(()),
-        _ => Err(
-            Error::from_kind(ErrorKind::Sys(errno::errno())).chain_err(|| "PR_CAPBSET_DROP error")
-        ),
+        _ => {
+            Err(Error::from_kind(ErrorKind::Sys(errno::errno()))
+                .chain_err(|| "PR_CAPBSET_DROP error"))
+        }
     }
 }
 
@@ -29,9 +30,10 @@ pub fn has_cap(cap: Capability) -> Result<bool> {
     match ret {
         0 => Ok(false),
         1 => Ok(true),
-        _ => Err(
-            Error::from_kind(ErrorKind::Sys(errno::errno())).chain_err(|| "PR_CAPBSET_READ error")
-        ),
+        _ => {
+            Err(Error::from_kind(ErrorKind::Sys(errno::errno()))
+                .chain_err(|| "PR_CAPBSET_READ error"))
+        }
     }
 }
 
