@@ -2,7 +2,7 @@
 
 use errno;
 
-error_chain!{
+error_chain! {
     errors {
         /// Parsing error due to invalid capability name.
         InvalidCapName(name: String) {
@@ -16,3 +16,11 @@ error_chain!{
         }
     }
 }
+
+#[test]
+fn test_sys_errno() {
+    let eperm = errno::Errno(1);
+    let err = ErrorKind::Sys(eperm);
+    assert!(err.description().contains("syscall failed"));
+    assert!(format!("{}", err).contains("Operation not permitted"));
+}
