@@ -16,9 +16,10 @@ pub fn has_keepcaps() -> Result<bool> {
     match ret {
         0 => Ok(false),
         1 => Ok(true),
-        _ => Err(
-            Error::from_kind(ErrorKind::Sys(errno::errno())).chain_err(|| "PR_GET_KEEPCAPS error")
-        ),
+        _ => {
+            Err(Error::from_kind(ErrorKind::Sys(errno::errno()))
+                .chain_err(|| "PR_GET_KEEPCAPS error"))
+        }
     }
 }
 
@@ -28,8 +29,9 @@ pub fn set_keepcaps(keep_caps: bool) -> Result<()> {
     let ret = unsafe { libc::prctl(nr::PR_SET_KEEPCAPS, flag, 0, 0) };
     match ret {
         0 => Ok(()),
-        _ => Err(
-            Error::from_kind(ErrorKind::Sys(errno::errno())).chain_err(|| "PR_SET_KEEPCAPS error")
-        ),
+        _ => {
+            Err(Error::from_kind(ErrorKind::Sys(errno::errno()))
+                .chain_err(|| "PR_SET_KEEPCAPS error"))
+        }
     }
 }
